import { Flex, message } from 'antd';
import styles from './index.less';
import { Fragment } from 'react/jsx-runtime';
import services from '@/services';
import { useEffect, useState } from 'react';

/**
 * @description 已接入行业系统
 */

const IndustrySystem = () => {

  const [list, setList] = useState<any>([])

  useEffect(() => {
    services.AuthApi.getIndustryListApi({
      groupId: 'INDUSTRY_APPLICATION'
    }).then(res => {
      console.log(res)
      if (res.code === 200) {
        setList(res.data)
      }
    })
  }, [])

  // const list = [
  //   {
  //     sub: [
  //       {
  //         name: '数字监管中心',
  //         sysNum: 1
  //       }
  //     ],
  //     sys: [
  //       {
  //         name: '成都市数字化城市管理信息系统',
  //         url: 'http://171.221.172.80:6888/eUrbanMIS/view/standardScreen.html',
  //         targetAppCode: 'szcg'
  //       },
  //     ]
  //   },
  //   {
  //     sub: [
  //       {
  //         name: '环卫处',
  //         sysNum: 1
  //       }
  //     ],
  //     sys: [
  //       {
  //         name: '成都市环卫固废智慧监管服务平台市级项目(一期)',
  //         url: 'https://cdgfhw.cloudhw.cn:58083/',
  //         targetAppCode: '58e0b55ec76cb32a8592259f7ebe5ff3'
  //       },
  //     ]
  //   },
  //   {
  //     sub: [
  //       {
  //         name: '城研院',
  //         sysNum: 1
  //       }
  //     ],
  //     sys: [
  //       {
  //         name: '成都市城市综合管理数据资源中心',
  //         url: 'https://10.1.214.169:18199/governPortal/#/portalHome',
  //       },
  //     ]
  //   },
  //   {
  //     sub: [
  //       {
  //         name: '执法总队',
  //         sysNum: 2
  //       }
  //     ],
  //     sys: [
  //       {
  //         name: '综合行政执法智慧服务平台',
  //         url: 'https://zhzf.tfryb.com',
  //         targetAppCode: '6833d686ae22d5ff6734282ed31c40f8'
  //       },
  //       {
  //         name: '违法建设治理系统',
  //         url: 'https://wjzl.cdcgzfzd.cn:1234/#/suspected-lbuilt/list',
  //         targetAppCode: '47b58d1aed051a60ef41f5adc2981922'
  //       },
  //     ]
  //   },
  //   {
  //     sub: [
  //       {
  //         name: '照明监管中心',
  //         sysNum: 1
  //       }
  //     ],
  //     sys: [
  //       {
  //         name: '成都市城市照明综合监管平台',
  //         url: 'https://service.cdzmjg.cn:8443/?1736578151849#/login',
  //         targetAppCode: 'e24f12d3114be1013c3fb6ce2bbde16b'
  //       },
  //     ]
  //   },
  //   {
  //     sub: [
  //       {
  //         name: '道桥监管中心',
  //         sysNum: 4
  //       },
  //     ],
  //     sys: [
  //       {
  //         name: '城市桥梁健康监测系统',
  //         url: 'https://jk.cddqgl.com/#/login',
  //         targetAppCode: 'a92c9fe8e1c91b79b041183c2824f56e'
  //       },
  //       {
  //         name: '占用挖掘城市道路信息管理平台（一期）',
  //         url: 'https://gl.cdzdwj.com/',
  //         targetAppCode: 'd3f4644a8a915f62a8c3e1437c054827'
  //       },
  //       {
  //         name: '成都市城市道路桥梁监控中心综合应用平台',
  //         url: 'https://zhyy.cddqgl.com:8082/',
  //         targetAppCode: '9c5e527cd39d8ef0ab4e624e52f0fb79'
  //       },
  //       {
  //         name: '成都市道路桥梁管理信息系统',
  //         url: 'https://www.cddqgl.com/enovia/toLogin',
  //         targetAppCode: 'e86654dbfc83ebd06afd7493aa5ddfbf'
  //       },
  //     ]
  //   },
  //   {
  //     sub: [
  //       {
  //         name: '建筑垃圾处',
  //         sysNum: 1
  //       },
  //     ],
  //     sys: [
  //       {
  //         name: '成都市工地扬尘监控及建筑垃圾运输处置信息和监管平台',
  //         url: 'http://221.237.182.174:8011/',
  //         targetAppCode: '58517dc5a1beba7974123ffae79112a2'
  //       }
  //     ]
  //   }
  // ];

  return (
    <Flex vertical className={styles.wrap}>
      <Flex className={styles.header}>
        {/* <div>所属行业</div> */}
        <div>处室（单位）</div>
        <div>政务信息化系统</div>
      </Flex>
      <div className={styles.list}>
        {list.map((item: any) => (
          <Flex className={styles.listItem} align="center" key={item.unitName}>
            <Flex vertical gap={15} className={styles.name}>
              <Fragment>
                <div
                >{`${item.unitName}(${item.apps?.length})`}</div>
              </Fragment>
            </Flex>
            {
              <div>
                {item.apps.map((subItem: any) => (
                  <div
                    key={subItem.name}
                    className={styles.subName}
                    onClick={() => {
                      if (subItem.appId && subItem.linkType === '0') {
                        services.AuthApi.getSSOUrlApi({ targetAppCode: subItem.appId }).then(res => {
                          if (res.code === 200) {
                            window.open(res.data);
                          }
                        })
                      } else {
                        if (subItem?.url === '') {
                          message.error('暂未获取系统链接！');
                        } else {
                          window.open(subItem?.linkUrl);
                        }
                      }
                    }}
                  >
                    {subItem.name}
                  </div>
                ))}
              </div>
            }

          </Flex>
        ))}
      </div>
    </Flex>
  );
};

export default IndustrySystem;
